@@ -118,18 +118,18 @@ draw_default_surface (GtkNumerableIcon *self)
   cr = cairo_create (surface);
 
   cairo_arc (cr, DEFAULT_SURFACE_SIZE / 2., DEFAULT_SURFACE_SIZE / 2.,
-             DEFAULT_RADIUS, 0., 2 * M_PI);
+             DEFAULT_RADIUS, 0., 2 * G_PI);
 
   gdk_cairo_set_source_rgba (cr, self->priv->background);
   cairo_fill (cr);
 
   cairo_arc (cr, DEFAULT_SURFACE_SIZE / 2., DEFAULT_SURFACE_SIZE / 2.,
-             DEFAULT_RADIUS - DEFAULT_BORDER_SIZE, 0., 2 * M_PI);
+             DEFAULT_RADIUS - DEFAULT_BORDER_SIZE, 0., 2 * G_PI);
   gdk_cairo_set_source_rgba  (cr, self->priv->foreground);
   cairo_fill (cr);
 
   cairo_arc (cr, DEFAULT_SURFACE_SIZE / 2., DEFAULT_SURFACE_SIZE / 2.,
-             DEFAULT_RADIUS - 2 * DEFAULT_BORDER_SIZE, 0., 2 * M_PI);
+             DEFAULT_RADIUS - 2 * DEFAULT_BORDER_SIZE, 0., 2 * G_PI);
   gdk_cairo_set_source_rgba  (cr, self->priv->background);
   cairo_fill (cr);
 
@@ -157,7 +157,7 @@ draw_from_gradient (cairo_pattern_t *pattern)
   cairo_pattern_set_matrix (pattern, &matrix);
 
   cairo_arc (cr, DEFAULT_SURFACE_SIZE / 2., DEFAULT_SURFACE_SIZE / 2.,
-             DEFAULT_RADIUS, 0., 2 * M_PI);
+             DEFAULT_RADIUS, 0., 2 * G_PI);
 
   cairo_set_source (cr, pattern);
   cairo_fill (cr);
@@ -889,7 +889,7 @@ gtk_numerable_icon_set_style_context (GtkNumerableIcon *self,
  * If this method is called and an icon name was already set as
  * background for the icon, @icon will be used, i.e. the last method
  * called between gtk_numerable_icon_set_background_gicon() and
- * #gtk_numerable_icon_set_background_icon_name() has always priority.
+ * gtk_numerable_icon_set_background_icon_name() has always priority.
  *
  * Since: 3.0
  */
@@ -1008,7 +1008,7 @@ gtk_numerable_icon_get_background_icon_name (GtkNumerableIcon *self)
  *
  * Creates a new unthemed #GtkNumerableIcon.
  *
- * Returns: a new #GIcon
+ * Returns: (transfer full): a new #GIcon
  *
  * Since: 3.0
  */
@@ -1031,7 +1031,7 @@ gtk_numerable_icon_new (GIcon *base_icon)
  * to the passed #GtkStyleContext. This is a convenience constructor
  * that calls gtk_numerable_icon_set_style_context() internally.
  *
- * Returns: a new #GIcon
+ * Returns: (transfer full): a new #GIcon
  *
  * Since: 3.0
  */
